#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class Zi8HiddenSmash : Indicator
	{
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name = "Periodo Buy", Order = 5, GroupName = "Parameters")]
		public int PeriodBuy
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name = "Periodo Sell", Order = 10, GroupName = "Parameters")]
		public int PeriodSell
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0, double.MaxValue)]
		[Display(Name = "Percent Buy", Order = 15, GroupName = "Parameters")]
		public double PercentBuy
		{ get; set; }

		[NinjaScriptProperty]
		[Range(0, double.MaxValue)]
		[Display(Name = "Percent Sell", Order = 20, GroupName = "Parameters")]
		public double PercentSell
		{ get; set; }


		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Enter the description for your new custom Indicator here.";
				Name										= "Zi8HiddenSmash";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= true;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;

				PeriodBuy = 1;
				PeriodSell = 1;
				PercentBuy = 25;
				PercentSell = 75;
			}
			else if (State == State.Configure)
			{
			}
		}

		protected override void OnBarUpdate()
		{
			// Rango de la barra:
			double rango = High[0] - Low[0];

			// Posición del Close con respecto al Low, expresado como porcentaje sobre el rango:
			double centil = 100 * (Close[0] - Low[0]) / rango;

			if (CurrentBar >= PeriodBuy)
			{
				// ***********************************************************
				// 							Patrón Buy
				// ***********************************************************

				// Filtro que contempla el centil del cierre, y las posiciones 
				// relativas del High, Low y Close con respecto a sus MAX's 
				// respectivos en el período 'PeriodBuy' analizado.
				if (High[0] >= MAX(High, PeriodBuy)[1]
					&& Low[0] >= MAX(Low, PeriodBuy)[1]
					&& Close[0] >= MAX(Close, PeriodBuy)[1]
					&& centil <= PercentBuy)
				{
					// Se colorea el fondo de todas las barras que 
					// intervienen en los cálculos del patrón:
					for (int i = 0; i <= PeriodBuy; i++)
						BackBrushes[i] = Brushes.PaleGreen;

					// Se dibuja una flecha debajo de la última barra del patrón, 
					// que es en la cuál se ha detectado su aparición.
					Draw.ArrowUp(this, CurrentBar + "ArrowUp", true,
						0, Low[0] - 2 * TickSize, Brushes.Green);
				}
			}

			if (CurrentBar >= PeriodSell)
			{
				// ***********************************************************
				// 							Patrón Sell
				// ***********************************************************

				if (Low[0] <= MIN(Low, PeriodSell)[1]
					&& High[0] <= MIN(High, PeriodSell)[1]
					&& Close[0] <= MIN(Close, PeriodSell)[1]
					&& centil >= PercentSell)
				{
					for (int i = 0; i <= PeriodSell; i++)
						BackBrushes[i] = Brushes.Tomato;

					Draw.ArrowDown(this, CurrentBar + "ArrowDown", true,
						0, High[0] + 2 * TickSize, Brushes.Fuchsia);
				}
			}
		}
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private Zi8HiddenSmash[] cacheZi8HiddenSmash;
		public Zi8HiddenSmash Zi8HiddenSmash(int periodBuy, int periodSell, double percentBuy, double percentSell)
		{
			return Zi8HiddenSmash(Input, periodBuy, periodSell, percentBuy, percentSell);
		}

		public Zi8HiddenSmash Zi8HiddenSmash(ISeries<double> input, int periodBuy, int periodSell, double percentBuy, double percentSell)
		{
			if (cacheZi8HiddenSmash != null)
				for (int idx = 0; idx < cacheZi8HiddenSmash.Length; idx++)
					if (cacheZi8HiddenSmash[idx] != null && cacheZi8HiddenSmash[idx].PeriodBuy == periodBuy && cacheZi8HiddenSmash[idx].PeriodSell == periodSell && cacheZi8HiddenSmash[idx].PercentBuy == percentBuy && cacheZi8HiddenSmash[idx].PercentSell == percentSell && cacheZi8HiddenSmash[idx].EqualsInput(input))
						return cacheZi8HiddenSmash[idx];
			return CacheIndicator<Zi8HiddenSmash>(new Zi8HiddenSmash(){ PeriodBuy = periodBuy, PeriodSell = periodSell, PercentBuy = percentBuy, PercentSell = percentSell }, input, ref cacheZi8HiddenSmash);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.Zi8HiddenSmash Zi8HiddenSmash(int periodBuy, int periodSell, double percentBuy, double percentSell)
		{
			return indicator.Zi8HiddenSmash(Input, periodBuy, periodSell, percentBuy, percentSell);
		}

		public Indicators.Zi8HiddenSmash Zi8HiddenSmash(ISeries<double> input , int periodBuy, int periodSell, double percentBuy, double percentSell)
		{
			return indicator.Zi8HiddenSmash(input, periodBuy, periodSell, percentBuy, percentSell);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.Zi8HiddenSmash Zi8HiddenSmash(int periodBuy, int periodSell, double percentBuy, double percentSell)
		{
			return indicator.Zi8HiddenSmash(Input, periodBuy, periodSell, percentBuy, percentSell);
		}

		public Indicators.Zi8HiddenSmash Zi8HiddenSmash(ISeries<double> input , int periodBuy, int periodSell, double percentBuy, double percentSell)
		{
			return indicator.Zi8HiddenSmash(input, periodBuy, periodSell, percentBuy, percentSell);
		}
	}
}

#endregion
